#!/bin/sh
set -e

# Run this shell to download and upgrade the required packages,
# invoke the protbuf compiler, move the generated validate files
# to the proper location, and finally try to run main.

echo "upgrading packages..."
go install google.golang.org/protobuf/cmd/protoc-gen-go@latest

# Comment this line to lock down the version used by the code.
# Note this may be a different version than the installed binary.
# We just need access to validate.proto.
go get -u github.com/envoyproxy/protoc-gen-validate

# Comment this line to use a custom version of protoc-gen-validate
go install github.com/envoyproxy/protoc-gen-validate

go mod tidy

echo "running protoc..."
protoc --proto_path=. \
    --proto_path=$(go list -f '{{ .Dir }}' -m github.com/envoyproxy/protoc-gen-validate) \
	--go_out=. --go_opt=paths=source_relative --go-grpc_out=. --go-grpc_opt=paths=source_relative \
    --validate_out="lang=go,--go_opt=paths=source_relative:." \
    from/v1/types.proto from/yetanother/v1/types.proto to/v1/user.proto

# source_relative of . puts validation file in wrong location, could specify
# ../../ if known for sure that directory exists.  This is arguably another
# bug.
mv github.com/valtest/from/v1/*.go from/v1
mv github.com/valtest/from/yetanother/v1/*.go from/yetanother/v1
mv github.com/valtest/to/v1/*.go to/v1
rm -fr github.com

echo "running main..."
go run .